﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Drawing.Drawing2D;

namespace howto_select_hours
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // The selected hours.
        private int StartHour = 6;
        private int StopHour = 18;

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ResizeRedraw = true;
        }

        private void picHours_Paint(object sender, PaintEventArgs e)
        {
            DrawHours(picHours, e.Graphics, StartHour, StopHour);
        }

        // Draw the hour indicator on this PictureBox.
        private void DrawHours(PictureBox pic, Graphics gr, int start_hour, int stop_hour)
        {
            gr.Clear(Color.LightGreen);

            // Scale to fit a 24-hour period.
            const int margin = 3;
            float scale_x = XScale(pic);
            float hgt = pic.ClientSize.Height;
            float y1 = margin;
            float y2 = hgt - margin;

            // Draw the selected time range.
            RectangleF hours_rect =
                new RectangleF(
                    start_hour * scale_x, y1,
                    (stop_hour - start_hour) * scale_x, y2 - y1);
            gr.FillRectangle(Brushes.Blue, hours_rect);

            // Draw tick marks.
            float x = 0;
            for (int i = 0; i <= 24; i++)
            {
                gr.DrawLine(Pens.DarkGray, x, 0, x, hgt);
                x += scale_x;
            }

            // Draw times.
            gr.RotateTransform(-90);
            int xmid = -pic.ClientSize.Height / 2;
            using (Font font = new Font(FontFamily.GenericSansSerif, 12))
            {
                using (StringFormat sf = new StringFormat())
                {
                    sf.Alignment = StringAlignment.Center;
                    sf.LineAlignment = StringAlignment.Center;

                    x = 0;
                    for (int i = 0; i <= 24; i++)
                    {
                        gr.DrawString(HourToString(i), font,
                            Brushes.Black, xmid, x, sf);
                        x += scale_x;
                    }
                }
            }
        }

        // Return the hour formatted as we want to display it.
        private string HourToString(int hour)
        {
            if (hour == 0) return "midnight";
            if (hour == 12) return "noon";
            if (hour == 24) return "midnight";
            if (hour <= 12) return hour.ToString() + "am";
            return (hour - 12).ToString() + "pm";
        }

        // Get the horizontal scale factor.
        private float XScale(PictureBox pic)
        {
            return pic.ClientSize.Width / 24;
        }

        // Handle mouse events.
        private bool Drawing = false;
        private int DrawingStartHour, DrawingStopHour;
        private void picHours_MouseDown(object sender, MouseEventArgs e)
        {
            Drawing = true;
            DrawingStartHour = (int)Math.Round(e.X / XScale(picHours));
            DrawingStopHour = DrawingStartHour;
            StartHour = DrawingStartHour;
            StopHour = DrawingStartHour;
            picHours.Refresh();
        }

        private void picHours_MouseMove(object sender, MouseEventArgs e)
        {
            if (!Drawing) return;

            // Calculate the value and display a tooltip.
            int hour = (int)Math.Round(e.X / XScale(picHours));
            string new_tip = HourToString(hour);
            if (tipHour.GetToolTip(picHours) != new_tip)
                tipHour.SetToolTip(picHours, new_tip);

            // Save the new value.
            DrawingStopHour = hour;

            // Redraw.
            if (DrawingStartHour < DrawingStopHour)
            {
                StopHour = DrawingStopHour;
                StartHour = DrawingStartHour;
            }
            else
            {
                StartHour = DrawingStopHour;
                StopHour = DrawingStartHour;
            }
            picHours.Refresh();
        }

        private void picHours_MouseUp(object sender, MouseEventArgs e)
        {
            if (!Drawing) return;
            tipHour.SetToolTip(picHours, "");
            Drawing = false;
            DisplayTimes();
        }

        // Show the times in the TextBoxes.
        private void DisplayTimes()
        {
            DateTime start_time = new DateTime(2000, 1, 1, StartHour, 0, 0);
            DateTime stop_time = new DateTime(2000, 1, 1, StopHour, 0, 0);
            txtStartTime.Text = start_time.ToShortTimeString();
            txtStopTime.Text = stop_time.ToShortTimeString();
        }
    }
}
